var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { errorResponse, successResponse, } from "../../../models";
export var IsUrlValidErrorReason;
(function (IsUrlValidErrorReason) {
    IsUrlValidErrorReason["INVALID_URL_FORMAT"] = "INVALID_URL_FORMAT";
    IsUrlValidErrorReason["URL_DOES_NOT_EXIST"] = "URL_DOES_NOT_EXIST";
})(IsUrlValidErrorReason || (IsUrlValidErrorReason = {}));
export const isUrlValid = (_a) => __awaiter(void 0, [_a], void 0, function* ({ url, confirmExistenceOfUrl, }) {
    // Step 1: Validate URL format
    let parsedUrl;
    try {
        parsedUrl = new URL(url);
    }
    catch (e) {
        // If URL constructor throws, it's not a valid URL format
        return errorResponse(IsUrlValidErrorReason.INVALID_URL_FORMAT);
    }
    if (!confirmExistenceOfUrl) {
        return successResponse(true);
    }
    // Step 2: Attempt to fetch the URL using a HEAD request
    try {
        const response = yield fetch(parsedUrl.toString(), { method: "HEAD" });
        // Considering HTTP 200-level responses as "valid"
        if (response.ok) {
            return successResponse(true);
        }
        else {
            return errorResponse(IsUrlValidErrorReason.URL_DOES_NOT_EXIST);
        }
    }
    catch (e) {
        // If there's a network error or something else preventing the request
        return errorResponse(IsUrlValidErrorReason.URL_DOES_NOT_EXIST);
    }
});
//# sourceMappingURL=isUrlValid.js.map